Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Double ¶
type Double struct {
Size int
// contains filtered or unexported fields
}
func (*Double) ReverseTraverse ¶
func (d *Double) ReverseTraverse() []interface{}
type Single ¶
type Single struct {
Size int
// contains filtered or unexported fields
}
func (*Single) Delete ¶
Delete will delete the first node it maches It will return an error if the list is empty, or if the element was not in the list
func (*Single) ReverseTraverse ¶
func (s *Single) ReverseTraverse() []interface{}
ReverseTraverse returns an array of the linked list in a reversed order.
Click to show internal directories.
Click to hide internal directories.